[vlc-commits] commit: luatelnet: the oldtelnet options are now working well with the luatelnet module. ( Rémi Duraffort )

git at videolan.org git at videolan.org
Thu Jun 17 22:42:41 CEST 2010


vlc | branch: master | Rémi Duraffort <ivoire at videolan.org> | Thu Jun 17 22:39:48 2010 +0200| [db35e6905cec16d2e9f29bcbcfee394d536affd1] | committer: Rémi Duraffort 

luatelnet: the oldtelnet options are now working well with the luatelnet module.

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=db35e6905cec16d2e9f29bcbcfee394d536affd1
---

 modules/control/telnet.c |    2 +-
 modules/misc/lua/intf.c  |   70 +++++++++++++++++++++++++++++----------------
 modules/misc/lua/vlc.c   |   24 +++++++++++++++-
 3 files changed, 69 insertions(+), 27 deletions(-)

diff --git a/modules/control/telnet.c b/modules/control/telnet.c
index 0b63fd1..442c580 100644
--- a/modules/control/telnet.c
+++ b/modules/control/telnet.c
@@ -87,7 +87,7 @@ vlc_module_begin ()
     set_shortname( "Telnet" )
     set_category( CAT_INTERFACE )
     set_subcategory( SUBCAT_INTERFACE_CONTROL )
-    add_string( "telnet-host", "", NULL, TELNETHOST_TEXT,
+    add_string( "telnet-host", "localhost", NULL, TELNETHOST_TEXT,
                  TELNETHOST_LONGTEXT, true )
     add_integer( "telnet-port", TELNETPORT_DEFAULT, NULL, TELNETPORT_TEXT,
                  TELNETPORT_LONGTEXT, true )
diff --git a/modules/misc/lua/vlc.c b/modules/misc/lua/vlc.c
index e44e60d..ee0b057 100644
--- a/modules/misc/lua/vlc.c
+++ b/modules/misc/lua/vlc.c
@@ -69,6 +69,20 @@
 #define INDEX_TEXT N_( "Directory index" )
 #define INDEX_LONGTEXT N_( "Allow to build directory index" )
 
+#define TELNETHOST_TEXT N_( "Host" )
+#define TELNETHOST_LONGTEXT N_( "This is the host on which the " \
+    "interface will listen. It defaults to all network interfaces (0.0.0.0)." \
+    " If you want this interface to be available only on the local " \
+    "machine, enter \"127.0.0.1\"." )
+#define TELNETPORT_TEXT N_( "Port" )
+#define TELNETPORT_LONGTEXT N_( "This is the TCP port on which this " \
+    "interface will listen. It defaults to 4212." )
+#define TELNETPORT_DEFAULT 4212
+#define TELNETPWD_TEXT N_( "Password" )
+#define TELNETPWD_LONGTEXT N_( "A single administration password is used " \
+    "to protect this interface. The default value is \"admin\"." )
+#define TELNETPWD_DEFAULT "admin"
+
 static int vlc_sd_probe_Open( vlc_object_t * );
 
 vlc_module_begin ()
@@ -88,10 +102,18 @@ vlc_module_begin ()
                     INTF_TEXT, INTF_LONGTEXT, false )
         add_string( "lua-config", "", NULL,
                     CONFIG_TEXT, CONFIG_LONGTEXT, false )
-        set_section( N_("Lua HTTP" ), 0 )
+        set_section( N_("Lua HTTP"), 0 )
             add_string ( "http-host", NULL, NULL, HOST_TEXT, HOST_LONGTEXT, true )
             add_string ( "http-src",  NULL, NULL, SRC_TEXT,  SRC_LONGTEXT,  true )
             add_bool   ( "http-index", false, NULL, INDEX_TEXT, INDEX_LONGTEXT, true )
+        set_section( N_("Lua Telnet"), 0 )
+            add_string( "telnet-host", "localhost", NULL, TELNETHOST_TEXT,
+                        TELNETHOST_LONGTEXT, true )
+            add_integer( "telnet-port", TELNETPORT_DEFAULT, NULL, TELNETPORT_TEXT,
+                         TELNETPORT_LONGTEXT, true )
+            add_password( "telnet-password", TELNETPWD_DEFAULT, NULL, TELNETPWD_TEXT,
+                          TELNETPWD_LONGTEXT, true )
+
         set_callbacks( Open_LuaIntf, Close_LuaIntf )
 
     add_submodule ()



More information about the vlc-commits mailing list
diff --git a/modules/misc/lua/intf.c b/modules/misc/lua/intf.c
index 081f1b1..ea7b2af 100644
--- a/modules/misc/lua/intf.c
+++ b/modules/misc/lua/intf.c
@@ -214,45 +214,65 @@ int Open_LuaIntf( vlc_object_t *p_this )
 
     /*
      * Get the lua-config string.
      * If the string is empty, try with the old http-* options and build the righr line
      */
     psz_config = var_CreateGetNonEmptyString( p_intf, "lua-config" );
-    if( !psz_config && !strcmp( psz_name, "http" ) )
+    if( !psz_config )
     {
-        char *psz_http_host = var_CreateGetNonEmptyString( p_intf, "http-host" );
-        char *psz_http_src = var_CreateGetNonEmptyString( p_intf, "http-src" );
-        bool b_http_index = var_CreateGetBool( p_intf, "http-index" );
-        if( psz_http_host )
+        if( !strcmp( psz_name, "http" ) )
         {
-            char *psz_esc = config_StringEscape( psz_http_host );
-            asprintf( &psz_config, "http={host='%s'", psz_esc );
-            free( psz_esc );
-            free( psz_http_host );
-        }
-        if( psz_http_src )
-        {
-            char *psz_esc = config_StringEscape( psz_http_src );
+            char *psz_http_host = var_CreateGetNonEmptyString( p_intf, "http-host" );
+            char *psz_http_src = var_CreateGetNonEmptyString( p_intf, "http-src" );
+            bool b_http_index = var_CreateGetBool( p_intf, "http-index" );
+            if( psz_http_host )
+            {
+                char *psz_esc = config_StringEscape( psz_http_host );
+                asprintf( &psz_config, "http={host='%s'", psz_esc );
+                free( psz_esc );
+                free( psz_http_host );
+            }
+            if( psz_http_src )
+            {
+                char *psz_esc = config_StringEscape( psz_http_src );
+                if( psz_config )
+                {
+                    char *psz_tmp;
+                    asprintf( &psz_tmp, "%s,dir='%s'", psz_config, psz_esc );
+                    free( psz_config );
+                    psz_config = psz_tmp;
+                }
+                else
+                    asprintf( &psz_config, "http={dir='%s'", psz_esc );
+                free( psz_esc );
+                free( psz_http_src );
+            }
             if( psz_config )
             {
                 char *psz_tmp;
-                asprintf( &psz_tmp, "%s,dir='%s'", psz_config, psz_esc );
+                asprintf( &psz_tmp, "%s,no_index=%s}", psz_config, b_http_index ? "true" : "false" );
                 free( psz_config );
                 psz_config = psz_tmp;
             }
             else
-                asprintf( &psz_config, "http={dir='%s'", psz_esc );
-            free( psz_esc );
-            free( psz_http_src );
+                asprintf( &psz_config, "http={no_index=%s}", b_http_index ? "true" : "false" );
         }
-        if( psz_config )
+        else if( !strcmp( psz_name, "telnet" ) )
         {
-            char *psz_tmp;
-            asprintf( &psz_tmp, "%s,no_index=%s}", psz_config, b_http_index ? "true" : "false" );
-            free( psz_config );
-            psz_config = psz_tmp;
+            char *psz_telnet_host = var_CreateGetString( p_intf, "telnet-host" );
+            int i_telnet_port = var_CreateGetInteger( p_intf, "telnet-port" );
+            char *psz_telnet_passwd = var_CreateGetString( p_intf, "telnet-password" );
+
+            char *psz_esc_host = config_StringEscape( psz_telnet_host );
+            char *psz_esc_passwd = config_StringEscape( psz_telnet_passwd );
+
+            asprintf( &psz_config, "telnet={host='%s:%d',password='%s'}", psz_esc_host ? psz_esc_host : "", i_telnet_port, psz_esc_passwd );
+
+            free( psz_esc_host );
+            free( psz_esc_passwd );
+            free( psz_telnet_passwd );
+            free( psz_telnet_host );
         }
-        else
-            asprintf( &psz_config, "http={no_index=%s}", b_http_index ? "true" : "false" );
     }
 
     if( psz_config )
@@ -214,45 +214,65 @@ int Open_LuaIntf( vlc_object_t *p_this )
     /*
      * Get the lua-config string.
-     * If the string is empty, try with the old http-* options and build the righr line
+     * If the string is empty, try with the old http-* or telnet-* options
+     * and build the right configuration line
      */
     psz_config = var_CreateGetNonEmptyString( p_intf, "lua-config" );